#
# spec file for package foot
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           foot
Version:        1.11.0
Release:        bp154.1.18
Summary:        A Wayland terminal emulator
License:        MIT
URL:            https://codeberg.org/dnkl/foot
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Patch0:         foot-tests-missing-deps.patch
Requires:       terminfo
BuildRequires:  meson >= 0.54
BuildRequires:  pkgconfig
BuildRequires:  python3
BuildRequires:  scdoc
BuildRequires:  pkgconfig(fcft) < 4.0.0
BuildRequires:  pkgconfig(fcft) >= 3.0.0
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(libutf8proc)
BuildRequires:  pkgconfig(pixman-1)
BuildRequires:  pkgconfig(tic)
BuildRequires:  pkgconfig(tllist) >= 1.0.4
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  pkgconfig(wayland-scanner)
BuildRequires:  pkgconfig(xkbcommon) >= 1.0.0

%description
A Wayland terminal emulator.

%package extra-terminfo

Summary:        Extra terminfo files for the foot terminal emulator

%description extra-terminfo
This package contains extra terminfo files for the foot terminal emulator
that provide more features than the files in the terminfo-base package.
Set term=foot-extra or term=foot-extra-direct in foot.ini to
take advantage of the files in this package.

%prep
%autosetup -n %{name} -p1

%build
%meson -Db_lto=true
%meson_build

%install
%meson_install
mv %{buildroot}/%{_datadir}/terminfo/f/foot %{buildroot}/%{_datadir}/terminfo/f/foot-extra
mv %{buildroot}/%{_datadir}/terminfo/f/foot-direct %{buildroot}/%{_datadir}/terminfo/f/foot-extra-direct

%files
%license LICENSE
%doc README.md CHANGELOG.md
%{_bindir}/foot
%{_bindir}/footclient
%{_datadir}/applications/foot.desktop
%{_datadir}/applications/footclient.desktop
%{_datadir}/applications/foot-server.desktop
%{_datadir}/bash-completion/
%{_datadir}/doc/%{name}/
%{_datadir}/fish/
%{_datadir}/zsh/
%{_datadir}/%{name}/
%{_datadir}/icons/hicolor/
%{_mandir}/man1/foot.1.gz
%{_mandir}/man1/footclient.1.gz
%{_mandir}/man5/foot.ini.5.gz
%{_mandir}/man7/foot-ctlseqs.7.gz

%files extra-terminfo
%{_datadir}/terminfo/f/foot-extra
%{_datadir}/terminfo/f/foot-extra-direct

%changelog
* Sat Feb  5 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.11.0:
  * foot.ini options:
  * Added mouse-bindings.selection-override-modifiers option to specify
    which modifiers should be held to force selection and prevent
    client applications from grabbing the mouse.
  * scrollback.multiplier is now also applied in alternate-scroll mode.
    The client receives multiple arrow key presses equal to
    the multiplier instead of just one.
  * key-bindings.clipboard-{copy,paste} now support
    the XF86{Copy,Paste} keycodes.
  * irc:// and ircs:// URLs are now auto-detected as URLs.
  * Added support for reporting mouse coordinates in SGR-Pixels (1016) format.
  * Added XTGETTCAP support for reporting the current terminfo to clients
    that support it instead of needing the terminfo file installed,
    say when ssh'ing to remote hosts.
  * Added partial DECRQSS support so that clients can request
    top and bottom margins (DECSTBM), graphic rendition (SGR) and
    cursor style (DECSCUSR).
  * Searching the scrollback now defaults to searching for
    the previously-searched string.
  * PaperColorDark and PaperColorLight themes have been renamed to
    paper-color-dark and paper-color-light for consistency with other themes.
  * foot will now try to change the locale to either C.UTF-8 or en_US.UTF-8
    on startup if it has been started with a non-UTF-8 locale. If it fails to
    change the locale for any reason, it will show an error and not start
    the shell / program it was supposed to.
  * Pasting or dropping files on the alternate screen no longer quotes
    the filename.
  * Copying a line-based selection now includes a trailing newline.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.11.0 for more details.
- Patches:
  * Add foot-tests-missing-deps.patch to add missing wayland-client dependency
    to tests subdirectory, as discussed with upstream.
* Wed Dec  8 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.3:
  * Implemented support for all other modes of the Kitty keyboard protocol.
    See Kitty keyboard protocol docs for more details.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.3 for more details.
* Thu Dec  2 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.2:
  * foot.ini options:
  * tweak.grapheme-width-method can now be set to max, which means to use
    the width of the largest codepoint in the grapheme cluster.
  * Added initial support for Kitty keyboard protocol, currently with support
    for only the "Disambiguate escape codes" mode. See Kitty keyboard protocol
    docs for more details.
  * Right-clicking the CSD title bar now informs the Wayland compositor to show
    a window context menu, if the compositor supports such a thing in general.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.2 for more details.
* Mon Nov 22 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.1:
  * Fixed bugs in parsing foot.ini for letter-spacing, pipe-* key bindings, etc
    that were introduced in 1.10.0.
  * Added XDG desktop file for footclient.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.1 for more details.
* Sun Nov 21 2021 Arnav Singh <opensuse@arnavion.dev>
- Rename foot-direct-extra terminfo file to foot-extra-direct, to match
  upstream's wishes.
* Sun Nov 14 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.10.0:
  * foot.ini options:
  * Added notify-focus-inhibit boolean option to control whether
    desktop notifications should be inhibited when the terminal
    has keyboard focus.
  * Added colors.scrollback-indicator color-pair option to specify foreground
    and background colors for the scrollback indicator.
  * Added csd.border-width and csd.border-color to configure the width and
    color of the CSD border.
  * Added colors.dim0-7 options to configure custom "dim" colors.
  * Changed tweak.grapheme-shaping to be enabled by default.
  * Changed tweak.grapheme-width-method to be "wcswidth" by default.
  * All boolean options are now limited to "yes|true|on|1|no|false|off|0".
    Previously any numbers greater than 0 were treated as true, and anything
    else that wasn't "yes|true|on" was treated as false.
  * scrollback.multiplier is no longer applied when the alternate screen
    is in use.
  * Removed deprecated bell option. bell section (introduced in 1.8.0) should
    be used instead.
  * Removed deprecated url-launch, jump-label-letters and
    osc8-underline-options options. url section (introduced in 1.8.0) should
    be used instead.
  * Some pre-defined color themes are now available in /usr/share/foot/themes/
  * See https://codeberg.org/dnkl/foot/releases/tag/1.10.0 for more details.
* Thu Oct 14 2021 Arnav Singh <opensuse@arnavion.dev>
- Fix default TERM to be "foot" and not "foot-extra" as was intended.
- Add dependency on terminfo package since that is the package that ships
  ncurses upstream's terminfo for foot, not terminfo-base.
* Mon Oct  4 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.9.2:
  * foot.ini options:
  * New tweak.font-monospace-warn option to disable new warning when
    the primary font is not monospace.
  * dpi-aware=auto option now scales fonts using the monitor's DPI only when
    all monitors have a scaling factor of one.
  * foot's custom terminfos have been moved to the foot-extra-terminfo package,
    where they have been renamed to foot-extra. By default, foot no longer
    sets TERMINFO and expects to use the terminfo shipped by ncurses. If you
    want to use the customer terminfos instead, install
    the foot-extra-terminfo package and set term=foot-extra in
    your foot config.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.9.1 and
    https://codeberg.org/dnkl/foot/releases/tag/1.9.2 for more details.
* Fri Aug 27 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.9.0:
  * foot.ini options:
  * include directives for including files now expand ~ in the path.
  * New uri.uri-characters option to customize what characters are considered
    to be part of a URL.
  * If using a compositor with client-side decorations, the CSDs now show
    window titles.
  * foot's terminfo file is now installed under /usr/share/foot/terminfo
    so as to not conflict with terminfo-base's version of the file
    under /usr/share/terminfo. foot also sets the TERMINFO env var on
    the program to /usr/share/foot/terminfo so that the program prefers to
    use the file in this directory instead of terminfo-base's version.
    This is because terminfo-base's version does not expose all the capabilities
    that foot supports.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.9.0 for more details.
* Sun Jul 18 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.8.2:
  * New foot.ini options:
  * locked-title option to disable dynamic changes to the window title.
  * tweak.overflowing-glyps option to fix rendering issues with glyphs of
    any width that appear cut-off. This supersedes
    the tweak.allow-overflowing-double-width-glyphs and
    tweak.pua-double-width options, which have been removed.
  * See https://codeberg.org/dnkl/foot/releases/tag/1.8.2 for more details.
* Thu Jul  1 2021 Arnav Singh <opensuse@arnavion.dev>
- Delete 01-fix-xkbcommon-missing-dep.7edda924.patch since it is in upstream
  since 1.8.0
* Thu Jul  1 2021 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.8.1:
  * New foot.ini options:
  * cursor.beam-thickness
  * cursor.style=beam (cursor.style=bar remains a recognized value, but will
    will eventually be deprecated, and removed)
  * cursor.underline-thickness
  * underline-offset
  * csd.button-color
  * dedicated [bell] section, supporting multiple actions,
    a new command action to run an arbitrary command and
    XDG activation support. The bell option has been deprecated.
  * dedicated [url] section. The jump-label-letters, osc8-underline and
    url-launch options have been deprecated in favor of options in
    this new section.
  * tweak.grapheme-shaping option to foot.ini to support
    grapheme cluster segmentation and grapheme shaping.
    The grapheme cluster width is limited to two cells by default,
    which may cause cursor synchronization issues with many applications.
  * tweak.grapheme-width-method=wcswidth option to stop limiting
    grapheme cluster width to two cells.
  * tweak.pua-double-width option to foot.ini to force
    Private Usage Area codepoints to be treated as double-width characters.
  * Added support for including files in foot.ini
  * Added support for setting the full 256 color palette in foot.ini
  * Added ctrl+c as a default key binding; to cancel search/url mode.
  * Added support for overriding configuration options on the command line.
  * Added support for DECSET/DECRST 2026, as an alternative to the existing
    "synchronized updates" DCS sequences.
  * Added support for LS2 and LS3 (locking shift) escape sequences.
  * Added OSC 9 desktop notifications (iTerm2 compatible).
  * See https://codeberg.org/dnkl/foot/releases/tag/1.8.0 and
    https://codeberg.org/dnkl/foot/releases/tag/1.8.1 for more details.
* Sat Jun 12 2021 Jan Engelhardt <jengelh@inai.de>
- Remove unsubstantiated claims from descriptions.
* Fri Jun 11 2021 Arnav Singh <opensuse@arnavion.dev>
- Fix specfile to use correct URL, meson dependency to match upstream,
  and remove incorrect Group. Also use autosetup macro instead of setup.
* Fri Jun 11 2021 Arnav Singh <opensuse@arnavion.dev>
- Initial package of 1.7.2 for openSUSE
